# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2
from spounge.polykey.v2 import service_pb2 as polykey_dot_v2_dot_service__pb2


class PolykeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/GetKey',
                request_serializer=polykey_dot_v2_dot_service__pb2.GetKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_service__pb2.GetKeyResponse.FromString,
                _registered_method=True)
        self.ListKeys = channel.unary_unary(
                '/polykey.v2.PolykeyService/ListKeys',
                request_serializer=polykey_dot_v2_dot_service__pb2.ListKeysRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_service__pb2.ListKeysResponse.FromString,
                _registered_method=True)
        self.CreateKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/CreateKey',
                request_serializer=polykey_dot_v2_dot_service__pb2.CreateKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_service__pb2.CreateKeyResponse.FromString,
                _registered_method=True)
        self.RotateKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/RotateKey',
                request_serializer=polykey_dot_v2_dot_service__pb2.RotateKeyRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_service__pb2.RotateKeyResponse.FromString,
                _registered_method=True)
        self.RevokeKey = channel.unary_unary(
                '/polykey.v2.PolykeyService/RevokeKey',
                request_serializer=polykey_dot_v2_dot_service__pb2.RevokeKeyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.UpdateKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/UpdateKeyMetadata',
                request_serializer=polykey_dot_v2_dot_service__pb2.UpdateKeyMetadataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetKeyMetadata = channel.unary_unary(
                '/polykey.v2.PolykeyService/GetKeyMetadata',
                request_serializer=polykey_dot_v2_dot_service__pb2.GetKeyMetadataRequest.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_service__pb2.GetKeyMetadataResponse.FromString,
                _registered_method=True)
        self.HealthCheck = channel.unary_unary(
                '/polykey.v2.PolykeyService/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.FromString,
                _registered_method=True)


class PolykeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RotateKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKeyMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolykeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKey,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.GetKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_service__pb2.GetKeyResponse.SerializeToString,
            ),
            'ListKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKeys,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.ListKeysRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_service__pb2.ListKeysResponse.SerializeToString,
            ),
            'CreateKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKey,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.CreateKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_service__pb2.CreateKeyResponse.SerializeToString,
            ),
            'RotateKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RotateKey,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.RotateKeyRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_service__pb2.RotateKeyResponse.SerializeToString,
            ),
            'RevokeKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeKey,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.RevokeKeyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.UpdateKeyMetadataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetKeyMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKeyMetadata,
                    request_deserializer=polykey_dot_v2_dot_service__pb2.GetKeyMetadataRequest.FromString,
                    response_serializer=polykey_dot_v2_dot_service__pb2.GetKeyMetadataResponse.SerializeToString,
            ),
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'polykey.v2.PolykeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('polykey.v2.PolykeyService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PolykeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/GetKey',
            polykey_dot_v2_dot_service__pb2.GetKeyRequest.SerializeToString,
            polykey_dot_v2_dot_service__pb2.GetKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/ListKeys',
            polykey_dot_v2_dot_service__pb2.ListKeysRequest.SerializeToString,
            polykey_dot_v2_dot_service__pb2.ListKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/CreateKey',
            polykey_dot_v2_dot_service__pb2.CreateKeyRequest.SerializeToString,
            polykey_dot_v2_dot_service__pb2.CreateKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RotateKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RotateKey',
            polykey_dot_v2_dot_service__pb2.RotateKeyRequest.SerializeToString,
            polykey_dot_v2_dot_service__pb2.RotateKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RevokeKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/RevokeKey',
            polykey_dot_v2_dot_service__pb2.RevokeKeyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/UpdateKeyMetadata',
            polykey_dot_v2_dot_service__pb2.UpdateKeyMetadataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKeyMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/GetKeyMetadata',
            polykey_dot_v2_dot_service__pb2.GetKeyMetadataRequest.SerializeToString,
            polykey_dot_v2_dot_service__pb2.GetKeyMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/polykey.v2.PolykeyService/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            polykey_dot_v2_dot_metrics__pb2.HealthCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/key_types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/key_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1apolykey/v2/key_types.proto\x12\npolykey.v2*\x7f\n\x07KeyType\x12\x18\n\x14KEY_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10KEY_TYPE_API_KEY\x10\x01\x12\x14\n\x10KEY_TYPE_AES_256\x10\x02\x12\x15\n\x11KEY_TYPE_RSA_4096\x10\x03\x12\x17\n\x13KEY_TYPE_ECDSA_P384\x10\x04*\x8a\x01\n\tKeyStatus\x12\x1a\n\x16KEY_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11KEY_STATUS_ACTIVE\x10\x01\x12\x17\n\x13KEY_STATUS_ROTATING\x10\x02\x12\x19\n\x15KEY_STATUS_DEPRECATED\x10\x03\x12\x16\n\x12KEY_STATUS_REVOKED\x10\x04*\x8f\x01\n\x10RotationStrategy\x12!\n\x1dROTATION_STRATEGY_UNSPECIFIED\x10\x00\x12\x19\n\x15ROTATION_STRATEGY_HOT\x10\x01\x12\x1c\n\x18ROTATION_STRATEGY_STAGED\x10\x02\x12\x1f\n\x1bROTATION_STRATEGY_SCHEDULED\x10\x03\x42\xaa\x01\n\x0e\x63om.polykey.v2B\rKeyTypesProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.key_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\rKeyTypesProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_KEYTYPE']._serialized_start=42
  _globals['_KEYTYPE']._serialized_end=169
  _globals['_KEYSTATUS']._serialized_start=172
  _globals['_KEYSTATUS']._serialized_end=310
  _globals['_ROTATIONSTRATEGY']._serialized_start=313
  _globals['_ROTATIONSTRATEGY']._serialized_end=456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/resources.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/resources.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/common/v1/resources.proto\x12\x12nodus.v1.common.v1\x1a\x1egoogle/protobuf/duration.proto\"\x98\x02\n\x0eResourceLimits\x12:\n\x19max_concurrent_executions\x18\x01 \x01(\x05R\x17maxConcurrentExecutions\x12G\n\x12max_execution_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10maxExecutionTime\x12(\n\x10max_memory_bytes\x18\x03 \x01(\x03R\x0emaxMemoryBytes\x12$\n\x0emax_tool_calls\x18\x04 \x01(\x05R\x0cmaxToolCalls\x12\x31\n\x15max_output_size_bytes\x18\x05 \x01(\x03R\x12maxOutputSizeBytes\"\xa2\x02\n\x13ResourceConsumption\x12*\n\x11memory_used_bytes\x18\x01 \x01(\x03R\x0fmemoryUsedBytes\x12\x36\n\x17\x63pu_utilization_percent\x18\x02 \x01(\x02R\x15\x63puUtilizationPercent\x12)\n\x10network_requests\x18\x03 \x01(\x05R\x0fnetworkRequests\x12:\n\x19network_bytes_transferred\x18\x04 \x01(\x03R\x17networkBytesTransferred\x12@\n\x0etotal_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtotalDuration\"\xf3\x01\n\x14ResourceRequirements\x12\x34\n\x16\x65stimated_memory_bytes\x18\x01 \x01(\x03R\x14\x65stimatedMemoryBytes\x12H\n\x12\x65stimated_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x65stimatedDuration\x12\x36\n\x17\x65stimated_network_calls\x18\x03 \x01(\x05R\x15\x65stimatedNetworkCalls\x12#\n\rresource_tier\x18\x04 \x01(\tR\x0cresourceTierB\xdc\x01\n\x16\x63om.nodus.v1.common.v1B\x0eResourcesProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.resources_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\016ResourcesProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_RESOURCELIMITS']._serialized_start=91
  _globals['_RESOURCELIMITS']._serialized_end=371
  _globals['_RESOURCECONSUMPTION']._serialized_start=374
  _globals['_RESOURCECONSUMPTION']._serialized_end=664
  _globals['_RESOURCEREQUIREMENTS']._serialized_start=667
  _globals['_RESOURCEREQUIREMENTS']._serialized_end=910
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/direct.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/direct.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enodus/v1/nodes/v1/direct.proto\x12\x11nodus.v1.nodes.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\"\xb2\x03\n\x10\x44irectNodeConfig\x12\"\n\rmcp_server_id\x18\x01 \x01(\tR\x0bmcpServerId\x12\x1b\n\ttool_name\x18\x03 \x01(\tR\x08toolName\x12@\n\x0ftool_parameters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0etoolParameters\x12<\n\x0ctool_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0btoolTimeout\x12/\n\x13validate_parameters\x18\x06 \x01(\x08R\x12validateParameters\x12\x45\n\routput_format\x18\x07 \x01(\x0e\x32 .nodus.v1.common.v1.ResultFormatR\x0coutputFormat\x12%\n\x0e\x65xtract_fields\x18\x08 \x03(\tR\rextractFields\x12>\n\x07options\x18\t \x01(\x0b\x32$.nodus.v1.nodes.v1.DirectNodeOptionsR\x07options\"\x9a\x03\n\x11\x44irectNodeOptions\x12!\n\x0c\x63\x61\x63he_result\x18\x01 \x01(\x08R\x0b\x63\x61\x63heResult\x12\x36\n\tcache_ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08\x63\x61\x63heTtl\x12\x31\n\x14require_confirmation\x18\x03 \x01(\x08R\x13requireConfirmation\x12m\n\x13parameter_overrides\x18\x04 \x03(\x0b\x32<.nodus.v1.nodes.v1.DirectNodeOptions.ParameterOverridesEntryR\x12parameterOverrides\x12\x41\n\x0cretry_policy\x18\x05 \x01(\x0b\x32\x1e.nodus.v1.nodes.v1.RetryPolicyR\x0bretryPolicy\x1a\x45\n\x17ParameterOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x93\x02\n\x0bRetryPolicy\x12!\n\x0cmax_attempts\x18\x01 \x01(\x05R\x0bmaxAttempts\x12\x42\n\x0finitial_backoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0einitialBackoff\x12:\n\x0bmax_backoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nmaxBackoff\x12-\n\x12\x62\x61\x63koff_multiplier\x18\x04 \x01(\x02R\x11\x62\x61\x63koffMultiplier\x12\x32\n\x15retryable_error_codes\x18\x05 \x03(\tR\x13retryableErrorCodesB\xd2\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0b\x44irectProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.direct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\013DirectProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._loaded_options = None
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_DIRECTNODECONFIG']._serialized_start=148
  _globals['_DIRECTNODECONFIG']._serialized_end=582
  _globals['_DIRECTNODEOPTIONS']._serialized_start=585
  _globals['_DIRECTNODEOPTIONS']._serialized_end=995
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_start=926
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_end=995
  _globals['_RETRYPOLICY']._serialized_start=998
  _globals['_RETRYPOLICY']._serialized_end=1273
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import autonomous_pb2, autonomous_pb2_grpc, direct_pb2, direct_pb2_grpc, execution_pb2, execution_pb2_grpc, reasoning_pb2, reasoning_pb2_grpc, webhook_pb2, webhook_pb2_grpc

__all__ = ["autonomous_pb2", "autonomous_pb2_grpc", "direct_pb2", "direct_pb2_grpc", "execution_pb2", "execution_pb2_grpc", "reasoning_pb2", "reasoning_pb2_grpc", "webhook_pb2", "webhook_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v2/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'common/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ommon/v2/common.proto\x12\tcommon.v2\x1a\x1cgoogle/protobuf/struct.proto\"i\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x31\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x64\x65tails\"Z\n\x04\x46ile\x12\x1b\n\tfile_name\x18\x01 \x01(\tR\x08\x66ileName\x12\x1b\n\tmime_type\x18\x02 \x01(\tR\x08mimeType\x12\x18\n\x07\x63ontent\x18\x03 \x01(\x0cR\x07\x63ontent\"C\n\x10PaginationParams\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\"\x85\x01\n\x10PaginationResult\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1f\n\x0btotal_items\x18\x03 \x01(\x05R\ntotalItems\x12\x1f\n\x0btotal_pages\x18\x04 \x01(\x05R\ntotalPages\"\x1a\n\x08\x45ntityId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"~\n\x08Metadata\x12\x37\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1f.common.v2.Metadata.FieldsEntryR\x06\x66ields\x1a\x39\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa1\x01\n\rcom.common.v2B\x0b\x43ommonProtoP\x01Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\xa2\x02\x03\x43XX\xaa\x02\tCommon.V2\xca\x02\tCommon\\V2\xe2\x02\x15\x43ommon\\V2\\GPBMetadata\xea\x02\nCommon::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\rcom.common.v2B\013CommonProtoP\001Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\242\002\003CXX\252\002\tCommon.V2\312\002\tCommon\\V2\342\002\025Common\\V2\\GPBMetadata\352\002\nCommon::V2'
  _globals['_METADATA_FIELDSENTRY']._loaded_options = None
  _globals['_METADATA_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_STATUS']._serialized_start=67
  _globals['_STATUS']._serialized_end=172
  _globals['_FILE']._serialized_start=174
  _globals['_FILE']._serialized_end=264
  _globals['_PAGINATIONPARAMS']._serialized_start=266
  _globals['_PAGINATIONPARAMS']._serialized_end=333
  _globals['_PAGINATIONRESULT']._serialized_start=336
  _globals['_PAGINATIONRESULT']._serialized_end=469
  _globals['_ENTITYID']._serialized_start=471
  _globals['_ENTITYID']._serialized_end=497
  _globals['_METADATA']._serialized_start=499
  _globals['_METADATA']._serialized_end=625
  _globals['_METADATA_FIELDSENTRY']._serialized_start=568
  _globals['_METADATA_FIELDSENTRY']._serialized_end=625
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user/v2/user_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user/v2/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from spounge.iam.v2 import managed_secret_pb2 as iam_dot_v2_dot_managed__secret__pb2
from spounge.user.v2 import user_pb2 as user_dot_v2_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1auser/v2/user_service.proto\x12\x07user.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto\"H\n\x16GetUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile\"\x87\x01\n\x18UpdateUserProfileRequest\x12;\n\x0bupdate_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12.\n\x07profile\x18\x02 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile\"K\n\x19UpdateUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile\"\x88\x01\n\x17\x41\x64\x64ManagedSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x19.iam.v2.ManagedSecretTypeR\x04type\x12*\n\x11plain_text_secret\x18\x03 \x01(\tR\x0fplainTextSecret\"I\n\x18\x41\x64\x64ManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret\"M\n\x1aListManagedSecretsResponse\x12/\n\x07secrets\x18\x01 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x07secrets\"6\n\x17GetManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\"I\n\x18GetManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret\"9\n\x1a\x44\x65leteManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId\"H\n\x1b\x44\x65leteManagedSecretResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status2\xa7\x04\n\x0bUserService\x12K\n\x0eGetUserProfile\x12\x16.google.protobuf.Empty\x1a\x1f.user.v2.GetUserProfileResponse\"\x00\x12\\\n\x11UpdateUserProfile\x12!.user.v2.UpdateUserProfileRequest\x1a\".user.v2.UpdateUserProfileResponse\"\x00\x12Y\n\x10\x41\x64\x64ManagedSecret\x12 .user.v2.AddManagedSecretRequest\x1a!.user.v2.AddManagedSecretResponse\"\x00\x12S\n\x12ListManagedSecrets\x12\x16.google.protobuf.Empty\x1a#.user.v2.ListManagedSecretsResponse\"\x00\x12Y\n\x10GetManagedSecret\x12 .user.v2.GetManagedSecretRequest\x1a!.user.v2.GetManagedSecretResponse\"\x00\x12\x62\n\x13\x44\x65leteManagedSecret\x12#.user.v2.DeleteManagedSecretRequest\x1a$.user.v2.DeleteManagedSecretResponse\"\x00\x42\x98\x01\n\x0b\x63om.user.v2B\x10UserServiceProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\xa2\x02\x03UXX\xaa\x02\x07User.V2\xca\x02\x07User\\V2\xe2\x02\x13User\\V2\\GPBMetadata\xea\x02\x08User::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user.v2.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.user.v2B\020UserServiceProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\242\002\003UXX\252\002\007User.V2\312\002\007User\\V2\342\002\023User\\V2\\GPBMetadata\352\002\010User::V2'
  _globals['_GETUSERPROFILERESPONSE']._serialized_start=175
  _globals['_GETUSERPROFILERESPONSE']._serialized_end=247
  _globals['_UPDATEUSERPROFILEREQUEST']._serialized_start=250
  _globals['_UPDATEUSERPROFILEREQUEST']._serialized_end=385
  _globals['_UPDATEUSERPROFILERESPONSE']._serialized_start=387
  _globals['_UPDATEUSERPROFILERESPONSE']._serialized_end=462
  _globals['_ADDMANAGEDSECRETREQUEST']._serialized_start=465
  _globals['_ADDMANAGEDSECRETREQUEST']._serialized_end=601
  _globals['_ADDMANAGEDSECRETRESPONSE']._serialized_start=603
  _globals['_ADDMANAGEDSECRETRESPONSE']._serialized_end=676
  _globals['_LISTMANAGEDSECRETSRESPONSE']._serialized_start=678
  _globals['_LISTMANAGEDSECRETSRESPONSE']._serialized_end=755
  _globals['_GETMANAGEDSECRETREQUEST']._serialized_start=757
  _globals['_GETMANAGEDSECRETREQUEST']._serialized_end=811
  _globals['_GETMANAGEDSECRETRESPONSE']._serialized_start=813
  _globals['_GETMANAGEDSECRETRESPONSE']._serialized_end=886
  _globals['_DELETEMANAGEDSECRETREQUEST']._serialized_start=888
  _globals['_DELETEMANAGEDSECRETREQUEST']._serialized_end=945
  _globals['_DELETEMANAGEDSECRETRESPONSE']._serialized_start=947
  _globals['_DELETEMANAGEDSECRETRESPONSE']._serialized_end=1019
  _globals['_USERSERVICE']._serialized_start=1022
  _globals['_USERSERVICE']._serialized_end=1573
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.workflow.v2 import execution_service_pb2 as workflow_dot_v2_dot_execution__service__pb2


class ExecutionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartExecution = channel.unary_unary(
                '/workflow.v2.ExecutionService/StartExecution',
                request_serializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.FromString,
                _registered_method=True)
        self.GetExecution = channel.unary_unary(
                '/workflow.v2.ExecutionService/GetExecution',
                request_serializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.FromString,
                _registered_method=True)
        self.ListExecutions = channel.unary_unary(
                '/workflow.v2.ExecutionService/ListExecutions',
                request_serializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.FromString,
                _registered_method=True)
        self.CancelExecution = channel.unary_unary(
                '/workflow.v2.ExecutionService/CancelExecution',
                request_serializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.FromString,
                _registered_method=True)
        self.StreamExecution = channel.unary_stream(
                '/workflow.v2.ExecutionService/StreamExecution',
                request_serializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.SerializeToString,
                response_deserializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.FromString,
                _registered_method=True)


class ExecutionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExecutions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExecutionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.StartExecution,
                    request_deserializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.SerializeToString,
            ),
            'GetExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecution,
                    request_deserializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.SerializeToString,
            ),
            'ListExecutions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExecutions,
                    request_deserializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.SerializeToString,
            ),
            'CancelExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelExecution,
                    request_deserializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.SerializeToString,
            ),
            'StreamExecution': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExecution,
                    request_deserializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.FromString,
                    response_serializer=workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'workflow.v2.ExecutionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('workflow.v2.ExecutionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ExecutionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.ExecutionService/StartExecution',
            workflow_dot_v2_dot_execution__service__pb2.StartExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.StartExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.ExecutionService/GetExecution',
            workflow_dot_v2_dot_execution__service__pb2.GetExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.GetExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListExecutions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.ExecutionService/ListExecutions',
            workflow_dot_v2_dot_execution__service__pb2.ListExecutionsRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.ListExecutionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/workflow.v2.ExecutionService/CancelExecution',
            workflow_dot_v2_dot_execution__service__pb2.CancelExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.CancelExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/workflow.v2.ExecutionService/StreamExecution',
            workflow_dot_v2_dot_execution__service__pb2.StreamExecutionRequest.SerializeToString,
            workflow_dot_v2_dot_execution__service__pb2.StreamExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.api.v2 import workflow_gateway_service_pb2 as api_dot_v2_dot_workflow__gateway__service__pb2


class WorkflowGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWorkflow = channel.unary_unary(
                '/api.v2.WorkflowGatewayService/CreateWorkflow',
                request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.FromString,
                _registered_method=True)
        self.GetWorkflow = channel.unary_unary(
                '/api.v2.WorkflowGatewayService/GetWorkflow',
                request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.FromString,
                _registered_method=True)
        self.ListWorkflows = channel.unary_unary(
                '/api.v2.WorkflowGatewayService/ListWorkflows',
                request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.FromString,
                _registered_method=True)
        self.StartExecution = channel.unary_unary(
                '/api.v2.WorkflowGatewayService/StartExecution',
                request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.FromString,
                _registered_method=True)
        self.GetExecution = channel.unary_unary(
                '/api.v2.WorkflowGatewayService/GetExecution',
                request_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.FromString,
                _registered_method=True)


class WorkflowGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkflow(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWorkflows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWorkflow,
                    request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.FromString,
                    response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.SerializeToString,
            ),
            'GetWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkflow,
                    request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.FromString,
                    response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.SerializeToString,
            ),
            'ListWorkflows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWorkflows,
                    request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.FromString,
                    response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.SerializeToString,
            ),
            'StartExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.StartExecution,
                    request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.FromString,
                    response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.SerializeToString,
            ),
            'GetExecution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecution,
                    request_deserializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.FromString,
                    response_serializer=api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'api.v2.WorkflowGatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('api.v2.WorkflowGatewayService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkflowGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.WorkflowGatewayService/CreateWorkflow',
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceCreateWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.WorkflowGatewayService/GetWorkflow',
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetWorkflowResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWorkflows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.WorkflowGatewayService/ListWorkflows',
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceListWorkflowsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StartExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.WorkflowGatewayService/StartExecution',
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceStartExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExecution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.WorkflowGatewayService/GetExecution',
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionRequest.SerializeToString,
            api_dot_v2_dot_workflow__gateway__service__pb2.WorkflowGatewayServiceGetExecutionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user/v2/user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user/v2/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12user/v2/user.proto\x12\x07user.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x02\n\x0bUserProfile\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1a\n\x08username\x18\x03 \x01(\tR\x08username\x12\"\n\nfirst_name\x18\x04 \x01(\tH\x00R\tfirstName\x88\x01\x01\x12 \n\tlast_name\x18\x05 \x01(\tH\x01R\x08lastName\x88\x01\x01\x12/\n\x11profile_image_url\x18\x06 \x01(\tH\x02R\x0fprofileImageUrl\x88\x01\x01\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAtB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\x14\n\x12_profile_image_url\"b\n\x0f\x41\x63\x63ountSettings\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1a\n\x08timezone\x18\x02 \x01(\tR\x08timezone\x12\x1a\n\x08language\x18\x03 \x01(\tR\x08languageB\x91\x01\n\x0b\x63om.user.v2B\tUserProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\xa2\x02\x03UXX\xaa\x02\x07User.V2\xca\x02\x07User\\V2\xe2\x02\x13User\\V2\\GPBMetadata\xea\x02\x08User::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user.v2.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.user.v2B\tUserProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\242\002\003UXX\252\002\007User.V2\312\002\007User\\V2\342\002\023User\\V2\\GPBMetadata\352\002\010User::V2'
  _globals['_USERPROFILE']._serialized_start=65
  _globals['_USERPROFILE']._serialized_end=432
  _globals['_ACCOUNTSETTINGS']._serialized_start=434
  _globals['_ACCOUNTSETTINGS']._serialized_end=532
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/service.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x17polykey/v2/common.proto\x1a\x1apolykey/v2/key_types.proto\x1a\x18polykey/v2/metrics.proto\"\x85\x02\n\rGetKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12(\n\rskip_metadata\x18\x07 \x01(\x08H\x00R\x0cskipMetadata\x88\x01\x01\x42\x10\n\x0e_skip_metadata\"\x88\x02\n\x0eGetKeyResponse\x12:\n\x0ckey_material\x18\x01 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0bkeyMaterial\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12I\n\x12response_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12:\n\x19\x61uthorization_decision_id\x18\x04 \x01(\tR\x17\x61uthorizationDecisionId\"\xcc\x04\n\x0fListKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\x12\x30\n\tkey_types\x18\x05 \x03(\x0e\x32\x13.polykey.v2.KeyTypeR\x08keyTypes\x12\x31\n\x08statuses\x18\x06 \x03(\x0e\x32\x15.polykey.v2.KeyStatusR\x08statuses\x12L\n\x0btag_filters\x18\x07 \x03(\x0b\x32+.polykey.v2.ListKeysRequest.TagFiltersEntryR\ntagFilters\x12?\n\rcreated_after\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63reatedAfter\x12\x41\n\x0e\x63reated_before\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x1a=\n\x0fTagFiltersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfa\x01\n\x10ListKeysResponse\x12+\n\x04keys\x18\x01 \x03(\x0b\x32\x17.polykey.v2.KeyMetadataR\x04keys\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12%\n\x0e\x66iltered_count\x18\x05 \x01(\x05R\rfilteredCount\"\x94\x06\n\x10\x43reateKeyRequest\x12.\n\x08key_type\x18\x01 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12:\n\x04tags\x18\x04 \x03(\x0b\x32&.polykey.v2.CreateKeyRequest.TagsEntryR\x04tags\x12\x39\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\x1binitial_authorized_contexts\x18\x06 \x03(\tR\x19initialAuthorizedContexts\x12Y\n\x0f\x61\x63\x63\x65ss_policies\x18\x07 \x03(\x0b\x32\x30.polykey.v2.CreateKeyRequest.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12/\n\x13\x64\x61ta_classification\x18\x08 \x01(\tR\x12\x64\x61taClassification\x12_\n\x11generation_params\x18\t \x03(\x0b\x32\x32.polykey.v2.CreateKeyRequest.GenerationParamsEntryR\x10generationParams\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe6\x01\n\x11\x43reateKeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12:\n\x0ckey_material\x18\x03 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0bkeyMaterial\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\"\xc0\x03\n\x10RotateKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12\x38\n\x08strategy\x18\x03 \x01(\x0e\x32\x1c.polykey.v2.RotationStrategyR\x08strategy\x12\x30\n\x14grace_period_seconds\x18\x04 \x01(\x05R\x12gracePeriodSeconds\x12_\n\x11generation_params\x18\x05 \x03(\x0b\x32\x32.polykey.v2.RotateKeyRequest.GenerationParamsEntryR\x10generationParams\x12\x38\n\x18preserve_access_policies\x18\x06 \x01(\x08R\x16preserveAccessPolicies\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8a\x03\n\x11RotateKeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1f\n\x0bnew_version\x18\x02 \x01(\x05R\nnewVersion\x12)\n\x10previous_version\x18\x03 \x01(\x05R\x0fpreviousVersion\x12\x41\n\x10new_key_material\x18\x04 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0enewKeyMaterial\x12\x33\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12I\n\x12rotation_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11rotationTimestamp\x12O\n\x16old_version_expires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13oldVersionExpiresAt\"\xb6\x02\n\x10RevokeKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12+\n\x11revocation_reason\x18\x03 \x01(\tR\x10revocationReason\x12\x1c\n\timmediate\x18\x04 \x01(\x08R\timmediate\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x36\n\x17notify_external_systems\x18\x06 \x01(\x08R\x15notifyExternalSystems\"\x8e\x06\n\x18UpdateKeyMetadataRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12S\n\x0btags_to_add\x18\x04 \x03(\x0b\x32\x33.polykey.v2.UpdateKeyMetadataRequest.TagsToAddEntryR\ttagsToAdd\x12$\n\x0etags_to_remove\x18\x05 \x03(\tR\x0ctagsToRemove\x12&\n\x0f\x63ontexts_to_add\x18\x06 \x03(\tR\rcontextsToAdd\x12,\n\x12\x63ontexts_to_remove\x18\x07 \x03(\tR\x10\x63ontextsToRemove\x12h\n\x12policies_to_update\x18\x08 \x03(\x0b\x32:.polykey.v2.UpdateKeyMetadataRequest.PoliciesToUpdateEntryR\x10policiesToUpdate\x12>\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\texpiresAt\x88\x01\x01\x12\x34\n\x13\x64\x61ta_classification\x18\n \x01(\tH\x02R\x12\x64\x61taClassification\x88\x01\x01\x1a<\n\x0eTagsToAddEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15PoliciesToUpdateEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\r\n\x0b_expires_atB\x16\n\x14_data_classification\"\xbd\x02\n\x15GetKeyMetadataRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x34\n\x16include_access_history\x18\x04 \x01(\x08R\x14includeAccessHistory\x12\x34\n\x16include_policy_details\x18\x05 \x01(\x08R\x14includePolicyDetails\x12\x18\n\x07version\x18\x06 \x01(\x05R\x07version\"\x99\x03\n\x16GetKeyMetadataResponse\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12\x45\n\x0e\x61\x63\x63\x65ss_history\x18\x02 \x03(\x0b\x32\x1e.polykey.v2.AccessHistoryEntryR\raccessHistory\x12\\\n\x0epolicy_details\x18\x03 \x03(\x0b\x32\x35.polykey.v2.GetKeyMetadataResponse.PolicyDetailsEntryR\rpolicyDetails\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x1aZ\n\x12PolicyDetailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x18.polykey.v2.PolicyDetailR\x05value:\x02\x38\x01\x32\xe3\x04\n\x0ePolykeyService\x12?\n\x06GetKey\x12\x19.polykey.v2.GetKeyRequest\x1a\x1a.polykey.v2.GetKeyResponse\x12\x45\n\x08ListKeys\x12\x1b.polykey.v2.ListKeysRequest\x1a\x1c.polykey.v2.ListKeysResponse\x12H\n\tCreateKey\x12\x1c.polykey.v2.CreateKeyRequest\x1a\x1d.polykey.v2.CreateKeyResponse\x12H\n\tRotateKey\x12\x1c.polykey.v2.RotateKeyRequest\x1a\x1d.polykey.v2.RotateKeyResponse\x12\x41\n\tRevokeKey\x12\x1c.polykey.v2.RevokeKeyRequest\x1a\x16.google.protobuf.Empty\x12Q\n\x11UpdateKeyMetadata\x12$.polykey.v2.UpdateKeyMetadataRequest\x1a\x16.google.protobuf.Empty\x12W\n\x0eGetKeyMetadata\x12!.polykey.v2.GetKeyMetadataRequest\x1a\".polykey.v2.GetKeyMetadataResponse\x12\x46\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x1f.polykey.v2.HealthCheckResponseB\xa9\x01\n\x0e\x63om.polykey.v2B\x0cServiceProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014ServiceProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._loaded_options = None
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_options = b'8\001'
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._loaded_options = None
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_options = b'8\001'
  _globals['_GETKEYREQUEST']._serialized_start=182
  _globals['_GETKEYREQUEST']._serialized_end=443
  _globals['_GETKEYRESPONSE']._serialized_start=446
  _globals['_GETKEYRESPONSE']._serialized_end=710
  _globals['_LISTKEYSREQUEST']._serialized_start=713
  _globals['_LISTKEYSREQUEST']._serialized_end=1301
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_start=1240
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_end=1301
  _globals['_LISTKEYSRESPONSE']._serialized_start=1304
  _globals['_LISTKEYSRESPONSE']._serialized_end=1554
  _globals['_CREATEKEYREQUEST']._serialized_start=1557
  _globals['_CREATEKEYREQUEST']._serialized_end=2345
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_start=2154
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_end=2209
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_start=2211
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_end=2276
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_start=2278
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_end=2345
  _globals['_CREATEKEYRESPONSE']._serialized_start=2348
  _globals['_CREATEKEYRESPONSE']._serialized_end=2578
  _globals['_ROTATEKEYREQUEST']._serialized_start=2581
  _globals['_ROTATEKEYREQUEST']._serialized_end=3029
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_start=2278
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_end=2345
  _globals['_ROTATEKEYRESPONSE']._serialized_start=3032
  _globals['_ROTATEKEYRESPONSE']._serialized_end=3426
  _globals['_REVOKEKEYREQUEST']._serialized_start=3429
  _globals['_REVOKEKEYREQUEST']._serialized_end=3739
  _globals['_UPDATEKEYMETADATAREQUEST']._serialized_start=3742
  _globals['_UPDATEKEYMETADATAREQUEST']._serialized_end=4524
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_start=4340
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_end=4400
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_start=4402
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_end=4469
  _globals['_GETKEYMETADATAREQUEST']._serialized_start=4527
  _globals['_GETKEYMETADATAREQUEST']._serialized_end=4844
  _globals['_GETKEYMETADATARESPONSE']._serialized_start=4847
  _globals['_GETKEYMETADATARESPONSE']._serialized_end=5256
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_start=5166
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_end=5256
  _globals['_POLYKEYSERVICE']._serialized_start=5259
  _globals['_POLYKEYSERVICE']._serialized_end=5870
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.vector_db.v2 import vector_db_pb2 as vector__db_dot_v2_dot_vector__db__pb2


class VectorDBServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Upsert = channel.unary_unary(
                '/vector_db.v2.VectorDBService/Upsert',
                request_serializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.SerializeToString,
                response_deserializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.FromString,
                _registered_method=True)
        self.Query = channel.unary_unary(
                '/vector_db.v2.VectorDBService/Query',
                request_serializer=vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.SerializeToString,
                response_deserializer=vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.FromString,
                _registered_method=True)


class VectorDBServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Upsert(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VectorDBServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Upsert': grpc.unary_unary_rpc_method_handler(
                    servicer.Upsert,
                    request_deserializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.FromString,
                    response_serializer=vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.SerializeToString,
            ),
            'Query': grpc.unary_unary_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.FromString,
                    response_serializer=vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'vector_db.v2.VectorDBService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('vector_db.v2.VectorDBService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VectorDBService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Upsert(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/vector_db.v2.VectorDBService/Upsert',
            vector__db_dot_v2_dot_vector__db__pb2.UpsertRequest.SerializeToString,
            vector__db_dot_v2_dot_vector__db__pb2.UpsertResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/vector_db.v2.VectorDBService/Query',
            vector__db_dot_v2_dot_vector__db__pb2.QueryRequest.SerializeToString,
            vector__db_dot_v2_dot_vector__db__pb2.QueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Auto-generated __init__.py
from . import execution_pb2, execution_pb2_grpc, execution_service_pb2, execution_service_pb2_grpc, workflow_pb2, workflow_pb2_grpc, workflow_service_pb2, workflow_service_pb2_grpc

__all__ = ["execution_pb2", "execution_pb2_grpc", "execution_service_pb2", "execution_service_pb2_grpc", "workflow_pb2", "workflow_pb2_grpc", "workflow_service_pb2", "workflow_service_pb2_grpc"]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.auth.v2 import auth_service_pb2 as auth_dot_v2_dot_auth__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AuthServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
                '/auth.v2.AuthService/Login',
                request_serializer=auth_dot_v2_dot_auth__service__pb2.LoginRequest.SerializeToString,
                response_deserializer=auth_dot_v2_dot_auth__service__pb2.LoginResponse.FromString,
                _registered_method=True)
        self.RefreshToken = channel.unary_unary(
                '/auth.v2.AuthService/RefreshToken',
                request_serializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.FromString,
                _registered_method=True)
        self.Logout = channel.unary_unary(
                '/auth.v2.AuthService/Logout',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=auth_dot_v2_dot_auth__service__pb2.LogoutResponse.FromString,
                _registered_method=True)


class AuthServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Logout invalidates the user's session based on the provided auth token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth_dot_v2_dot_auth__service__pb2.LoginRequest.FromString,
                    response_serializer=auth_dot_v2_dot_auth__service__pb2.LoginResponse.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.FromString,
                    response_serializer=auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=auth_dot_v2_dot_auth__service__pb2.LogoutResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'auth.v2.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('auth.v2.AuthService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.v2.AuthService/Login',
            auth_dot_v2_dot_auth__service__pb2.LoginRequest.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.v2.AuthService/RefreshToken',
            auth_dot_v2_dot_auth__service__pb2.RefreshTokenRequest.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.RefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.v2.AuthService/Logout',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            auth_dot_v2_dot_auth__service__pb2.LogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Auto-generated __init__.py
from . import api_pb2, api_pb2_grpc, database_pb2, database_pb2_grpc, llm_pb2, llm_pb2_grpc, webhook_pb2, webhook_pb2_grpc

__all__ = ["api_pb2", "api_pb2_grpc", "database_pb2", "database_pb2_grpc", "llm_pb2", "llm_pb2_grpc", "webhook_pb2", "webhook_pb2_grpc"]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.bytestream import bytestream_pb2 as google_dot_bytestream_dot_bytestream__pb2


class ByteStreamStub(object):
    """#### Introduction

    The Byte Stream API enables a client to read and write a stream of bytes to
    and from a resource. Resources have names, and these names are supplied in
    the API calls below to identify the resource that is being read from or
    written to.

    All implementations of the Byte Stream API export the interface defined here:

    * `Read()`: Reads the contents of a resource.

    * `Write()`: Writes the contents of a resource. The client can call `Write()`
    multiple times with the same resource and can check the status of the write
    by calling `QueryWriteStatus()`.

    #### Service parameters and metadata

    The ByteStream API provides no direct way to access/modify any metadata
    associated with the resource.

    #### Errors

    The errors returned by the service are in the Google canonical error space.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Read = channel.unary_stream(
                '/google.bytestream.ByteStream/Read',
                request_serializer=google_dot_bytestream_dot_bytestream__pb2.ReadRequest.SerializeToString,
                response_deserializer=google_dot_bytestream_dot_bytestream__pb2.ReadResponse.FromString,
                _registered_method=True)
        self.Write = channel.stream_unary(
                '/google.bytestream.ByteStream/Write',
                request_serializer=google_dot_bytestream_dot_bytestream__pb2.WriteRequest.SerializeToString,
                response_deserializer=google_dot_bytestream_dot_bytestream__pb2.WriteResponse.FromString,
                _registered_method=True)
        self.QueryWriteStatus = channel.unary_unary(
                '/google.bytestream.ByteStream/QueryWriteStatus',
                request_serializer=google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusRequest.SerializeToString,
                response_deserializer=google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusResponse.FromString,
                _registered_method=True)


class ByteStreamServicer(object):
    """#### Introduction

    The Byte Stream API enables a client to read and write a stream of bytes to
    and from a resource. Resources have names, and these names are supplied in
    the API calls below to identify the resource that is being read from or
    written to.

    All implementations of the Byte Stream API export the interface defined here:

    * `Read()`: Reads the contents of a resource.

    * `Write()`: Writes the contents of a resource. The client can call `Write()`
    multiple times with the same resource and can check the status of the write
    by calling `QueryWriteStatus()`.

    #### Service parameters and metadata

    The ByteStream API provides no direct way to access/modify any metadata
    associated with the resource.

    #### Errors

    The errors returned by the service are in the Google canonical error space.
    """

    def Read(self, request, context):
        """`Read()` is used to retrieve the contents of a resource as a sequence
        of bytes. The bytes are returned in a sequence of responses, and the
        responses are delivered as the results of a server-side streaming RPC.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Write(self, request_iterator, context):
        """`Write()` is used to send the contents of a resource as a sequence of
        bytes. The bytes are sent in a sequence of request protos of a client-side
        streaming RPC.

        A `Write()` action is resumable. If there is an error or the connection is
        broken during the `Write()`, the client should check the status of the
        `Write()` by calling `QueryWriteStatus()` and continue writing from the
        returned `committed_size`. This may be less than the amount of data the
        client previously sent.

        Calling `Write()` on a resource name that was previously written and
        finalized could cause an error, depending on whether the underlying service
        allows over-writing of previously written resources.

        When the client closes the request channel, the service will respond with
        a `WriteResponse`. The service will not view the resource as `complete`
        until the client has sent a `WriteRequest` with `finish_write` set to
        `true`. Sending any requests on a stream after sending a request with
        `finish_write` set to `true` will cause an error. The client **should**
        check the `WriteResponse` it receives to determine how much data the
        service was able to commit and whether the service views the resource as
        `complete` or not.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryWriteStatus(self, request, context):
        """`QueryWriteStatus()` is used to find the `committed_size` for a resource
        that is being written, which can then be used as the `write_offset` for
        the next `Write()` call.

        If the resource does not exist (i.e., the resource has been deleted, or the
        first `Write()` has not yet reached the service), this method returns the
        error `NOT_FOUND`.

        The client **may** call `QueryWriteStatus()` at any time to determine how
        much data has been processed for this resource. This is useful if the
        client is buffering data and needs to know which data can be safely
        evicted. For any sequence of `QueryWriteStatus()` calls for a given
        resource name, the sequence of returned `committed_size` values will be
        non-decreasing.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ByteStreamServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Read': grpc.unary_stream_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=google_dot_bytestream_dot_bytestream__pb2.ReadRequest.FromString,
                    response_serializer=google_dot_bytestream_dot_bytestream__pb2.ReadResponse.SerializeToString,
            ),
            'Write': grpc.stream_unary_rpc_method_handler(
                    servicer.Write,
                    request_deserializer=google_dot_bytestream_dot_bytestream__pb2.WriteRequest.FromString,
                    response_serializer=google_dot_bytestream_dot_bytestream__pb2.WriteResponse.SerializeToString,
            ),
            'QueryWriteStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryWriteStatus,
                    request_deserializer=google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusRequest.FromString,
                    response_serializer=google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'google.bytestream.ByteStream', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('google.bytestream.ByteStream', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ByteStream(object):
    """#### Introduction

    The Byte Stream API enables a client to read and write a stream of bytes to
    and from a resource. Resources have names, and these names are supplied in
    the API calls below to identify the resource that is being read from or
    written to.

    All implementations of the Byte Stream API export the interface defined here:

    * `Read()`: Reads the contents of a resource.

    * `Write()`: Writes the contents of a resource. The client can call `Write()`
    multiple times with the same resource and can check the status of the write
    by calling `QueryWriteStatus()`.

    #### Service parameters and metadata

    The ByteStream API provides no direct way to access/modify any metadata
    associated with the resource.

    #### Errors

    The errors returned by the service are in the Google canonical error space.
    """

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/google.bytestream.ByteStream/Read',
            google_dot_bytestream_dot_bytestream__pb2.ReadRequest.SerializeToString,
            google_dot_bytestream_dot_bytestream__pb2.ReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Write(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/google.bytestream.ByteStream/Write',
            google_dot_bytestream_dot_bytestream__pb2.WriteRequest.SerializeToString,
            google_dot_bytestream_dot_bytestream__pb2.WriteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QueryWriteStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/google.bytestream.ByteStream/QueryWriteStatus',
            google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusRequest.SerializeToString,
            google_dot_bytestream_dot_bytestream__pb2.QueryWriteStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Auto-generated __init__.py
from . import api_key_pb2, api_key_pb2_grpc, managed_secret_pb2, managed_secret_pb2_grpc

__all__ = ["api_key_pb2", "api_key_pb2_grpc", "managed_secret_pb2", "managed_secret_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/service/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/service/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spounge.nodus.v1.nodes.v1 import execution_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2
from spounge.nodus.v1.mcp.v1 import connection_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/service/v1/service.proto\x12\x13nodus.v1.service.v1\x1a\x1cgoogle/api/annotations.proto\x1a!nodus/v1/nodes/v1/execution.proto\x1a nodus/v1/mcp/v1/connection.proto\".\n\x12\x43heckHealthRequest\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\"\xda\x01\n\x13\x43heckHealthResponse\x12N\n\x06status\x18\x01 \x01(\x0e\x32\x36.nodus.v1.service.v1.CheckHealthResponse.ServingStatusR\x06status\"s\n\rServingStatus\x12&\n\"SERVING_STATUS_UNKNOWN_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERVING_STATUS_SERVING\x10\x01\x12\x1e\n\x1aSERVING_STATUS_NOT_SERVING\x10\x02\x32\x9c\x06\n\x0cNodusService\x12z\n\x0b\x45xecuteNode\x12%.nodus.v1.nodes.v1.ExecuteNodeRequest\x1a&.nodus.v1.nodes.v1.ExecuteNodeResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/nodes:execute:\x01*\x12\x94\x01\n\x11\x45xecuteNodeStream\x12+.nodus.v1.nodes.v1.ExecuteNodeStreamRequest\x1a,.nodus.v1.nodes.v1.ExecuteNodeStreamResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/nodes:executeStream:\x01*0\x01\x12\x8f\x01\n\x11RegisterMCPServer\x12).nodus.v1.mcp.v1.RegisterMCPServerRequest\x1a*.nodus.v1.mcp.v1.RegisterMCPServerResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/mcp/servers:register:\x01*\x12z\n\x0eListMCPServers\x12&.nodus.v1.mcp.v1.ListMCPServersRequest\x1a\'.nodus.v1.mcp.v1.ListMCPServersResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/mcp/servers\x12u\n\rQueryMCPTools\x12%.nodus.v1.mcp.v1.QueryMCPToolsRequest\x1a&.nodus.v1.mcp.v1.QueryMCPToolsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/mcp/tools\x12t\n\x0b\x43heckHealth\x12\'.nodus.v1.service.v1.CheckHealthRequest\x1a(.nodus.v1.service.v1.CheckHealthResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/healthB\xe1\x01\n\x17\x63om.nodus.v1.service.v1B\x0cServiceProtoP\x01ZIgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/service/v1;servicev1\xa2\x02\x03NVS\xaa\x02\x13Nodus.V1.Service.V1\xca\x02\x13Nodus\\V1\\Service\\V1\xe2\x02\x1fNodus\\V1\\Service\\V1\\GPBMetadata\xea\x02\x16Nodus::V1::Service::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.service.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.nodus.v1.service.v1B\014ServiceProtoP\001ZIgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/service/v1;servicev1\242\002\003NVS\252\002\023Nodus.V1.Service.V1\312\002\023Nodus\\V1\\Service\\V1\342\002\037Nodus\\V1\\Service\\V1\\GPBMetadata\352\002\026Nodus::V1::Service::V1'
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNode']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNode']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/nodes:execute:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNodeStream']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNodeStream']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/nodes:executeStream:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['RegisterMCPServer']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['RegisterMCPServer']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/mcp/servers:register:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['ListMCPServers']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ListMCPServers']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/mcp/servers'
  _globals['_NODUSSERVICE'].methods_by_name['QueryMCPTools']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['QueryMCPTools']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/mcp/tools'
  _globals['_NODUSSERVICE'].methods_by_name['CheckHealth']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['CheckHealth']._serialized_options = b'\202\323\344\223\002\014\022\n/v1/health'
  _globals['_CHECKHEALTHREQUEST']._serialized_start=157
  _globals['_CHECKHEALTHREQUEST']._serialized_end=203
  _globals['_CHECKHEALTHRESPONSE']._serialized_start=206
  _globals['_CHECKHEALTHRESPONSE']._serialized_end=424
  _globals['_CHECKHEALTHRESPONSE_SERVINGSTATUS']._serialized_start=309
  _globals['_CHECKHEALTHRESPONSE_SERVINGSTATUS']._serialized_end=424
  _globals['_NODUSSERVICE']._serialized_start=427
  _globals['_NODUSSERVICE']._serialized_end=1223
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import connection_pb2, connection_pb2_grpc, server_pb2, server_pb2_grpc, tool_pb2, tool_pb2_grpc

__all__ = ["connection_pb2", "connection_pb2_grpc", "server_pb2", "server_pb2_grpc", "tool_pb2", "tool_pb2_grpc"]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.api.v2 import user_gateway_service_pb2 as api_dot_v2_dot_user__gateway__service__pb2


class UserGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
                '/api.v2.UserGatewayService/GetUserProfile',
                request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
                _registered_method=True)
        self.UpdateUserProfile = channel.unary_unary(
                '/api.v2.UserGatewayService/UpdateUserProfile',
                request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
                response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
                _registered_method=True)


class UserGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserProfile,
                    request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.FromString,
                    response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.SerializeToString,
            ),
            'UpdateUserProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserProfile,
                    request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.FromString,
                    response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'api.v2.UserGatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('api.v2.UserGatewayService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.UserGatewayService/GetUserProfile',
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateUserProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/api.v2.UserGatewayService/UpdateUserProfile',
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Auto-generated __init__.py
from . import common_pb2, common_pb2_grpc, key_types_pb2, key_types_pb2_grpc, metrics_pb2, metrics_pb2_grpc, service_pb2, service_pb2_grpc

__all__ = ["common_pb2", "common_pb2_grpc", "key_types_pb2", "key_types_pb2_grpc", "metrics_pb2", "metrics_pb2_grpc", "service_pb2", "service_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/execution_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/execution_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spounge.workflow.v2 import execution_pb2 as workflow_dot_v2_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#workflow/v2/execution_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bworkflow/v2/execution.proto\"\xbf\x01\n\x15StartExecutionRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12.\n\x10workflow_version\x18\x02 \x01(\x05H\x00R\x0fworkflowVersion\x88\x01\x01\x12@\n\x0finitial_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0einitialContextB\x13\n\x11_workflow_version\"V\n\x16StartExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution\"8\n\x13GetExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\"T\n\x14GetExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution\"u\n\x15ListExecutionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination\"\x95\x01\n\x16ListExecutionsResponse\x12>\n\nexecutions\x18\x01 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\nexecutions\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination\";\n\x16\x43\x61ncelExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\"D\n\x17\x43\x61ncelExecutionResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\";\n\x16StreamExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\"W\n\x17StreamExecutionResponse\x12<\n\x06update\x18\x01 \x01(\x0b\x32$.workflow.v2.WorkflowExecutionUpdateR\x06update2\xe5\x03\n\x10\x45xecutionService\x12[\n\x0eStartExecution\x12\".workflow.v2.StartExecutionRequest\x1a#.workflow.v2.StartExecutionResponse\"\x00\x12U\n\x0cGetExecution\x12 .workflow.v2.GetExecutionRequest\x1a!.workflow.v2.GetExecutionResponse\"\x00\x12[\n\x0eListExecutions\x12\".workflow.v2.ListExecutionsRequest\x1a#.workflow.v2.ListExecutionsResponse\"\x00\x12^\n\x0f\x43\x61ncelExecution\x12#.workflow.v2.CancelExecutionRequest\x1a$.workflow.v2.CancelExecutionResponse\"\x00\x12`\n\x0fStreamExecution\x12#.workflow.v2.StreamExecutionRequest\x1a$.workflow.v2.StreamExecutionResponse\"\x00\x30\x01\x42\xb9\x01\n\x0f\x63om.workflow.v2B\x15\x45xecutionServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.execution_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\025ExecutionServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_STARTEXECUTIONREQUEST']._serialized_start=136
  _globals['_STARTEXECUTIONREQUEST']._serialized_end=327
  _globals['_STARTEXECUTIONRESPONSE']._serialized_start=329
  _globals['_STARTEXECUTIONRESPONSE']._serialized_end=415
  _globals['_GETEXECUTIONREQUEST']._serialized_start=417
  _globals['_GETEXECUTIONREQUEST']._serialized_end=473
  _globals['_GETEXECUTIONRESPONSE']._serialized_start=475
  _globals['_GETEXECUTIONRESPONSE']._serialized_end=559
  _globals['_LISTEXECUTIONSREQUEST']._serialized_start=561
  _globals['_LISTEXECUTIONSREQUEST']._serialized_end=678
  _globals['_LISTEXECUTIONSRESPONSE']._serialized_start=681
  _globals['_LISTEXECUTIONSRESPONSE']._serialized_end=830
  _globals['_CANCELEXECUTIONREQUEST']._serialized_start=832
  _globals['_CANCELEXECUTIONREQUEST']._serialized_end=891
  _globals['_CANCELEXECUTIONRESPONSE']._serialized_start=893
  _globals['_CANCELEXECUTIONRESPONSE']._serialized_end=961
  _globals['_STREAMEXECUTIONREQUEST']._serialized_start=963
  _globals['_STREAMEXECUTIONREQUEST']._serialized_end=1022
  _globals['_STREAMEXECUTIONRESPONSE']._serialized_start=1024
  _globals['_STREAMEXECUTIONRESPONSE']._serialized_end=1111
  _globals['_EXECUTIONSERVICE']._serialized_start=1114
  _globals['_EXECUTIONSERVICE']._serialized_end=1599
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spounge.nodus.v1.mcp.v1 import connection_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2
from spounge.nodus.v1.nodes.v1 import execution_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2
from spounge.nodus.v1.service.v1 import service_pb2 as nodus_dot_v1_dot_service_dot_v1_dot_service__pb2


class NodusServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteNode = channel.unary_unary(
                '/nodus.v1.service.v1.NodusService/ExecuteNode',
                request_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.FromString,
                _registered_method=True)
        self.ExecuteNodeStream = channel.unary_stream(
                '/nodus.v1.service.v1.NodusService/ExecuteNodeStream',
                request_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.FromString,
                _registered_method=True)
        self.RegisterMCPServer = channel.unary_unary(
                '/nodus.v1.service.v1.NodusService/RegisterMCPServer',
                request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.FromString,
                _registered_method=True)
        self.ListMCPServers = channel.unary_unary(
                '/nodus.v1.service.v1.NodusService/ListMCPServers',
                request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.FromString,
                _registered_method=True)
        self.QueryMCPTools = channel.unary_unary(
                '/nodus.v1.service.v1.NodusService/QueryMCPTools',
                request_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.FromString,
                _registered_method=True)
        self.CheckHealth = channel.unary_unary(
                '/nodus.v1.service.v1.NodusService/CheckHealth',
                request_serializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.SerializeToString,
                response_deserializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.FromString,
                _registered_method=True)


class NodusServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExecuteNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteNodeStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterMCPServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMCPServers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryMCPTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckHealth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NodusServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ExecuteNode': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteNode,
                    request_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.SerializeToString,
            ),
            'ExecuteNodeStream': grpc.unary_stream_rpc_method_handler(
                    servicer.ExecuteNodeStream,
                    request_deserializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.SerializeToString,
            ),
            'RegisterMCPServer': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterMCPServer,
                    request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.SerializeToString,
            ),
            'ListMCPServers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMCPServers,
                    request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.SerializeToString,
            ),
            'QueryMCPTools': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryMCPTools,
                    request_deserializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.SerializeToString,
            ),
            'CheckHealth': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckHealth,
                    request_deserializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.FromString,
                    response_serializer=nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nodus.v1.service.v1.NodusService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('nodus.v1.service.v1.NodusService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class NodusService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExecuteNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/ExecuteNode',
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeRequest.SerializeToString,
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExecuteNodeStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/ExecuteNodeStream',
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamRequest.SerializeToString,
            nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2.ExecuteNodeStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterMCPServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/RegisterMCPServer',
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.RegisterMCPServerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMCPServers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/ListMCPServers',
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.ListMCPServersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QueryMCPTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/QueryMCPTools',
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsRequest.SerializeToString,
            nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2.QueryMCPToolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CheckHealth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nodus.v1.service.v1.NodusService/CheckHealth',
            nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthRequest.SerializeToString,
            nodus_dot_v1_dot_service_dot_v1_dot_service__pb2.CheckHealthResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
